@@ -7,7 +7,7 @@ class CarrierSchema(CamelCaseSchema):
   class Meta:
     unknown = EXCLUDE
 
-  id = fields.UUID()
+  id = fields.UUID(allow_none=True)
   mc = fields.String(allow_none=True)
   dot = fields.String(allow_none=True)
   customer_code = fields.String(allow_none=True)
@@ -49,7 +49,7 @@ class CarrierSchema(CamelCaseSchema):
   not_reached_count_first_updated_at = fields.Date()
   lane_count = fields.Integer(allow_none=True)
   has_teams = fields.Boolean()
-  contact = fields.Nested(ContactSchema)
+  contact = fields.Nested(ContactSchema, allow_none=True)
   account_carrier_maps = fields.List(fields.Nested(AccountCarrierMapSchema))
 
   @post_load
