@@ -6,8 +6,8 @@ class ContactSchema(CamelCaseSchema):
   class Meta:
     unknown = EXCLUDE
 
-  id = fields.UUID()
-  carrier_id = fields.UUID()
+  id = fields.UUID(allow_none=True)
+  carrier_id = fields.UUID(allow_none=True)
   first_name = fields.String()
   last_name = fields.String(allow_none=True)
   phone = fields.String()
