@@ -205,7 +205,7 @@ def __get_google_location(city, state, zipcode, logger):
           data['city'] = component['short_name']
         elif 'administrative_area_level_1' in component['types']:
           data['state'] = component['short_name']
-        elif 'postcode' in component['types']:
+        elif 'postcode' in component['types'] or 'postal_code' in component['types']:
           data['postcode'] = component['short_name']
         elif 'country' in component['types']:
           data['country'] = component['short_name']
