@@ -1,6 +1,8 @@
+import uuid
 from dataclasses import dataclass, field
 
 @dataclass
 class Equipment:
 
+    id: uuid.UUID
     name: str
\ No newline at end of file
