@@ -19,6 +19,6 @@ class BookLoadNotification:
       sns_service = SnsService()
       sns_service.send(self._app_config.BOOK_LOAD_SNS_TOPIC_ARN,
         self._app_config.BOOK_LOAD_SNS_SUBJECT, message)
-    except: 
-      logger.debug(f"failed to send message to {self._app_config.BOOK_LOAD_SNS_TOPIC_ARN}: {message}")
-      
+    except Exception as e:
+      logger.exception(f"failed to send message to {self._app_config.BOOK_LOAD_SNS_TOPIC_ARN}: {message} - {e}", e)
+
